@@ -5,6 +5,12 @@ class InternetProtocol:
         self.protocol = name
         self.protocols[name] = self
 
+    def __str__(self):
+        return self.protocol
+
+    def __repr__(self):
+        return f'<InternetProtocol {self.protocol}>'
+
     @classmethod
     def get(cls, name):
         if isinstance(name, cls):
